/******************************************************************************
*                             Print8021asClockInfo.c                          *
*******************************************************************************
*
* Description:
*    This example demonstrates how to get 802.1as clock information.
*
* Requirements:
*    For this example you need a PXI-6683(H) board.
*
* Instructions for Running:
*    1. Update 'deviceName' with the name of your NI-Sync device.
*    2. Run make.
*    3. Start and set the 802.1AS time reference using the StartStop8021AS 
*       and SetTimeReference examples.
*    4. Run the generated program.
*
******************************************************************************/

#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

ViStatus getStringAttribute (ViSession deviceSession, ViAttr attribute, ViChar** buffer)
{
    // Get buffer size
    ViInt32 bufferSize = niSync_GetAttributeViString (deviceSession, "",
                                                      attribute, 0,
                                                      VI_NULL);
    if (bufferSize <= 0)
    {
        return bufferSize;
    }

    *buffer = calloc(bufferSize, sizeof(ViChar));
    if (*buffer == NULL)
    {
        printf ("Error: unable to allocate memory of size %d\n", bufferSize);
        return -1;
    }

    ViStatus bufferStatus = niSync_GetAttributeViString (deviceSession, "",
                                                         attribute, bufferSize,
                                                         *buffer);
    return bufferStatus;
}

int main(void) 
{
    ViRsrc    deviceName = "PXI1Slot2";

    ViSession deviceSession = 0;
    ViChar*   grandMasterClockId = NULL;
    ViInt32   grandMasterClockAccuracy = 0;
    ViInt32   grandMasterClockClass = 0;
    ViInt32   grandMasterClockPriority1 = 0;
    ViInt32   grandMasterClockPriority2 = 0;
    ViChar*   localClockId = NULL;
    ViInt32   localClockAccuracy = 0;
    ViInt32   localClockClass = 0;
    ViInt32   localClockPriority1 = 0;
    ViInt32   localClockPriority2 = 0;
    ViUInt32  timeSeconds = 0;
    ViUInt32  timeNsec = 0;
    ViUInt16  timeFractionalNsec = 0;
    ViInt32   logSyncInterval = 0;
    ViInt32   logAnnounceInterval = 0;
    ViBoolean asCapable = VI_FALSE;
    ViInt32   portState = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];
    char      c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_FALSE, &deviceSession));

    niSyncErrorCheck (getStringAttribute (deviceSession,
                                          NISYNC_ATTR_8021AS_GRANDMASTER_CLOCK_ID,
                                          &grandMasterClockId));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_GRANDMASTER_CLOCK_ACCURACY,
                                                  &grandMasterClockAccuracy));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_GRANDMASTER_CLOCK_CLASS,
                                                  &grandMasterClockClass));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_GRANDMASTER_PRIORITY1,
                                                  &grandMasterClockPriority1));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_GRANDMASTER_PRIORITY2,
                                                  &grandMasterClockPriority2));

    niSyncErrorCheck (getStringAttribute (deviceSession,
                                          NISYNC_ATTR_8021AS_CLOCK_ID,
                                          &localClockId));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_CLOCK_ACCURACY,
                                                  &localClockAccuracy));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_CLOCK_CLASS,
                                                  &localClockClass));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_PRIORITY1,
                                                  &localClockPriority1));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_PRIORITY2,
                                                  &localClockPriority2));

    niSyncErrorCheck (niSync_GetTime (deviceSession,
                                      &timeSeconds,
                                      &timeNsec,
                                      &timeFractionalNsec));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_LOG_SYNC_INTERVAL,
                                                  &logSyncInterval));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_LOG_ANNOUNCE_INTERVAL,
                                                  &logAnnounceInterval));

    niSyncErrorCheck (niSync_GetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_8021AS_AS_CAPABLE,
                                                    &asCapable));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_8021AS_PORT_STATE,
                                                  &portState));

    printf ("Grandmaster clock id:\t\t%s\n", grandMasterClockId);
    printf ("Grandmaster clock accuracy:\t%d\n", grandMasterClockAccuracy);
    printf ("Grandmaster clock class:\t%d\n", grandMasterClockClass);
    printf ("Grandmaster clock priority1:\t%d\n", grandMasterClockPriority1);
    printf ("Grandmaster clock priority2:\t%d\n", grandMasterClockPriority2);
    printf ("Clock id:\t\t\t%s\n", localClockId);
    printf ("Clock accuracy:\t\t\t%d\n", localClockAccuracy);
    printf ("Clock class:\t\t\t%d\n", localClockClass);
    printf ("Clock priority1:\t\t%d\n", localClockPriority1);
    printf ("Clock priority2:\t\t%d\n", localClockPriority2);
    printf ("Time seconds:\t\t\t%d\n", timeSeconds);
    printf ("Time nanoseconds:\t\t%d\n", timeNsec);
    printf ("Time fractional nanoseconds:\t%d\n", timeFractionalNsec);
    printf ("Log sync interval:\t\t%d\n", logSyncInterval);
    printf ("Log announce interval:\t\t%d\n", logAnnounceInterval);
    printf ("AS capable:\t\t\t%s\n", asCapable ? "True" : "False");
    printf ("Port state:\t\t\t%d\n", portState);

Error:
    // Free the buffer memory
    free (grandMasterClockId);
    free (localClockId);

    // Close session
    if (deviceSession)
        niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n", status, errorString);
    }

    printf ("End of program, press Enter to exit.");
    while ((c = getchar ()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}