/******************************************************************************
*                             PrintGPSSignalInfo.c                            *
*******************************************************************************
*
* Description:
*    This example demonstrates how to get GPS related information.
*
* Requirements:
*    For this example you need a PXI-6683(H) board.
*    The time reference needs to be set to GPS.
*
* Instructions for Running:
*    1. Update 'deviceName' with the name of your NI-Sync device.
*    2. Run make.
*    3. Run the generated program.
*
******************************************************************************/

#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main (void)
{
    ViRsrc deviceName = "PXI1Slot2";

    ViBoolean antennaConn = VI_FALSE;
    ViInt32   numberOfSatellites = 0;
    ViInt32   selfSurveyPercentage = 0;
    ViInt32   gpsStatus = 0;
    ViUInt32  timeSeconds = 0;
    ViUInt32  timeNanoseconds = 0;
    ViUInt16  timeFractionalNanoseconds = 0;
    ViInt32   utcOffset = 0;
    ViBoolean utcOffsetValid = VI_FALSE;
    ViSession deviceSession = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];
    char      c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_FALSE, &deviceSession));

    niSyncErrorCheck (niSync_GetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_GPS_ANTENNA_CONNECTED,
                                                    &antennaConn));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_GPS_SATELLITES_AVAILABLE,
                                                  &numberOfSatellites));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_GPS_SELF_SURVEY,
                                                  &selfSurveyPercentage));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_GPS_STATUS,
                                                  &gpsStatus));

    niSyncErrorCheck (niSync_GetTime (deviceSession,
                                      &timeSeconds,
                                      &timeNanoseconds,
                                      &timeFractionalNanoseconds));

    niSyncErrorCheck (niSync_GetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_TIMEREF_UTC_OFFSET,
                                                  &utcOffset));

    niSyncErrorCheck (niSync_GetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_TIMEREF_UTC_OFFSET_VALID,
                                                    &utcOffsetValid));

    printf ("Antenna connected:\t\t%s\n"
            "Number of satellites:\t\t%d\n"
            "Self-survey complete:\t\t%d\n",
            antennaConn ? "True" : "False", numberOfSatellites, selfSurveyPercentage);

    printf ("GPS status:\t\t\t%d\n", gpsStatus);

    printf ("GPS time seconds:\t\t%d\n"
            "GPS time nanoseconds:\t\t%d\n"
            "GPS fractional nanoseconds:\t%d\n",
            timeSeconds, timeNanoseconds, timeFractionalNanoseconds);

    printf ("UTC offset:\t\t\t%d\nUTC offset valid:\t\t%s\n",
            utcOffset, utcOffsetValid ? "True" : "False");

Error:
    // Close session
    if (deviceSession)
        niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n", status, errorString);
    }

    printf ("End of program, press Enter to exit.");
    while ((c = getchar ()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}