/******************************************************************************
*                            PrintLocationAndVelocity.c                       *
*******************************************************************************
*
* Description
*    This example demonstrates how to get location and velocity data.
*
* Requirements:
*    For this example you need a PXI-6683(H) board.
*    The time reference needs to be set to GPS.
*
* Instructions for Running:
*    1. Update 'deviceName' with the name of your NI-Sync device.
*    2. Run make.
*    3. Run the generated program.
*
******************************************************************************/

#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main (void)
{
    ViRsrc    deviceName = "PXI1Slot2";

    ViBoolean mobileModeEnabled = VI_FALSE;
    ViBoolean recalculatePositionOnReboot = VI_FALSE;
    ViReal64  altitude;
    ViReal64  eastVelocity;
    ViReal64  latitude;
    ViReal64  longitude;
    ViReal64  northVelocity;
    ViReal64  upVelocity;
    ViSession deviceSession = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];
    char      c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_FALSE, &deviceSession));

    niSyncErrorCheck (niSync_GetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_GPS_MOBILE_MODE,
                                                    &mobileModeEnabled));
    
    niSyncErrorCheck (niSync_GetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_GPS_RECALCULATE_POSITION,
                                                    &recalculatePositionOnReboot));

    niSyncErrorCheck (niSync_GetLocation (deviceSession,
                                          &latitude,
                                          &longitude,
                                          &altitude));

    niSyncErrorCheck (niSync_GetVelocity (deviceSession,
                                          &eastVelocity,
                                          &northVelocity,
                                          &upVelocity));

    printf ("Location latitude:\t%lf\n"
            "Location longitude:\t%lf\n"
            "Location altitude:\t%lf\n",
            latitude, longitude, altitude);

    printf ("East velocity:\t\t%lf\n"
            "North velocity:\t\t%lf\n"
            "Up velocity:\t\t%lf\n",
            eastVelocity, northVelocity, upVelocity);

    printf ("Mobile Mode:\t\t%s\n"
            "Recalculate Position:\t%s\n",
            mobileModeEnabled ? "True" : "False",
            recalculatePositionOnReboot ? "True" : "False");

Error:

    // Close session
    if (deviceSession)
       niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n", status, errorString);
    }

    printf ("End of program, press Enter to exit.");
    while ((c = getchar ()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}
