/******************************************************************************
*                                 RouteTrigger.c                              *
*******************************************************************************
*
* Description
*    This example demonstrates how to connect PFI0 from the front-panel to
*    PXI_Trig0 on the backplane.
*    This can be modified to make supported routes between any of the trigger
*    terminals.
*
* Instructions for Running
*    1. Update 'deviceName' to the name of your NI-Sync device.
*    2. Update 'srcTerminal' and 'destTerminal' to the terminal names you want
*       to connect. Look up the terminal names in the nisync.h header file.
*    3. Run the generated program after running make.
*
******************************************************************************/

#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main (void)
{
    ViRsrc           deviceName = "PXI1Slot2";

    ViConstString    srcTerminal = NISYNC_VAL_PFI0;
    ViConstString    destTerminal = NISYNC_VAL_PXITRIG0;
    ViSession        deviceSession = 0;
    ViInt32          status = 0;
    ViChar           errorString[256];
    char             c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_TRUE, &deviceSession));

    // Route the trigger source to the trigger destination
    niSyncErrorCheck (niSync_ConnectTrigTerminals (deviceSession,
                                                   srcTerminal,
                                                   destTerminal,
                                                   NISYNC_VAL_SYNC_CLK_ASYNC,
                                                   NISYNC_VAL_DONT_INVERT,
                                                   NISYNC_VAL_UPDATE_EDGE_RISING));

    // Wait for user input
    printf ("%s is routed to %s.\n", srcTerminal, destTerminal);
    printf ("Press Enter to disconnect the route.");
    while ((c = getchar()) != '\n' && c != EOF);

    // Disconnect the previously routed trigger terminals
    niSyncErrorCheck (niSync_DisconnectTrigTerminals (deviceSession,
                                                      srcTerminal,
                                                      destTerminal));

Error:
    // Close session
    if (deviceSession)
        niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n",status, errorString);
    }

    printf ("End of program, press Enter to continue.");
    while ((c = getchar()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}