/******************************************************************************
*                   Set1588LogSyncIntervalAndPriorities.c                     *
*******************************************************************************
*
* Description:
*    This example demonstrates how to set 1588 log sync interval and priorities.
*
* Requirements:
*    For this example you need a PXI-6683(H) board.
*    The time reference needs to be set to 1588.
*
* Instructions for Running:
*    1. Update 'deviceName' with the name of your NI-Sync device.
*    2. Update 'logSyncInterval', 'clockPriority1' and 'clockPriority2' 
*       with the desired values.
*    3. Run make.
*    4. Run the generated program. 
*
******************************************************************************/

#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main(void) {

    ViRsrc  deviceName = "PXI1Slot2";
    ViInt32 logSyncInterval = 0;
    ViInt32 clockPriority1 = 128;
    ViInt32 clockPriority2 = 128;

    ViSession deviceSession = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];
    char      c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_FALSE, &deviceSession));

    // Set log sync interval
    niSyncErrorCheck (niSync_SetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_1588_LOG_SYNC_INTERVAL,
                                                  logSyncInterval));

    // Set clock priority 1
    niSyncErrorCheck (niSync_SetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_1588_PRIORITY1,
                                                  clockPriority1));

    // Set clock priority 2
    niSyncErrorCheck (niSync_SetAttributeViInt32 (deviceSession,
                                                  "",
                                                  NISYNC_ATTR_1588_PRIORITY2,
                                                  clockPriority2));

Error:

    // Close session
    if (deviceSession)
        niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n", status, errorString);
    }

    printf ("End of program, press Enter to exit.");
    while ((c = getchar ()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}