/******************************************************************************
*                                 SetBoardTime.c                              *
*******************************************************************************
*
* Description
*    This example demonstrates how to set the board time.
*
* Instructions for Running
*    1. Update 'deviceName' to the name of your NI-Sync device.
*    2. Update 'timeSource' to the desired time source value:
*       NISYNC_VAL_INIT_TIME_SRC_SYSTEM_CLK - niSync_SetTime will use
*       the system time as input.
*       NISYNC_VAL_INIT_TIME_SRC_MANUAL - niSync_SetTime will use the time
*       specified by 'timeSeconds', 'timeNanoseconds' and timeFractionalNanoseconds'
*       as input.
*    3. If the timesource is set to NISYNC_VAL_INIT_TIME_SRC_MANUAL, update 
*       'timeSeconds', 'timeNanoseconds' and 'timeFractionalNanoseconds'
*       to the desired time values.
*    4. Run the generated program after running make.
*
******************************************************************************/
#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main (void)
{
    ViRsrc   deviceName = "PXI1Slot2";
    ViInt32  timeSource = NISYNC_VAL_INIT_TIME_SRC_MANUAL;
    ViUInt32 timeSeconds = 1514764800;
    ViUInt32 timeNanoseconds = 0;
    ViUInt16 timeFractionalNanoseconds = 0;
    ViReal64 timerefCorrection = 0;

    ViSession deviceSession = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];
    char      c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_TRUE, &deviceSession));

    // Set the board time
    niSyncErrorCheck (niSync_SetTime (deviceSession,
                                      timeSource,
                                      timeSeconds,
                                      timeNanoseconds,
                                      timeFractionalNanoseconds));

Error:
    // Close session
    if (deviceSession)
       niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n",status, errorString);
    }
    else
        printf ("Attributes have been set.\n");

    printf ("End of program, press Enter to continue.");
    while ((c = getchar()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}
