/******************************************************************************
*                    SetMobileModeAndRecalculatePosition.c                    *
*******************************************************************************
*
* Description
*    This example demonstrates how to set mobile mode and recalculate position,
*    then persist configuration.
*
* Instructions for Running
*    1. Update 'deviceName' to the name of your NI-Sync device.
*    2. Update 'mobileModeEnabled', 'recalculatePositionOnReboot' and 
*        'persistConfiguration' to the desired values.
*    3. Run the generated program after running make.
*
******************************************************************************/
#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main (void)
{
    ViRsrc    deviceName = "PXI1Slot2";
    ViBoolean mobileModeEnabled = VI_FALSE;
    ViBoolean recalculatePositionOnReboot = VI_TRUE;
    ViBoolean persistConfiguration = VI_TRUE;
    
    ViSession deviceSession = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];
    char      c;

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_TRUE, &deviceSession));

    // Set mobile mode
    niSyncErrorCheck (niSync_SetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_GPS_MOBILE_MODE,
                                                    mobileModeEnabled));
    
    // Set recalculate position on reboot
    niSyncErrorCheck (niSync_SetAttributeViBoolean (deviceSession,
                                                    "",
                                                    NISYNC_ATTR_GPS_RECALCULATE_POSITION,
                                                    recalculatePositionOnReboot));

    // Persist the configuration
    if (persistConfiguration)
        niSyncErrorCheck (niSync_PersistConfig (deviceSession));

Error:

    // Close session
    if (deviceSession)
       niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
        niSync_error_message (VI_NULL, status, errorString);

        printf ("Error %d occurred: %s\n",status, errorString);
    }
    else
        printf ("Attributes have been set.\n");

    printf ("End of program, press Enter to continue.");
    while ((c = getchar()) != '\n' && c != EOF);
    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}