/******************************************************************************
*                               StartStop1588.c                               *
*******************************************************************************
*
* Description
*    This example demonstrates how to start and stop 1588.
*
* Instructions for Running
*    1. Update 'deviceName' to the name of your NI-Sync device.
*    2. Update 'start1588': 1 - start; 0 - stop.
*    3. Run the generated program after running make.
*
******************************************************************************/

#include <nisync.h>
#include <stdio.h>
#include <stdlib.h>

#define niSyncErrorCheck(fCall) if (status = (fCall), status < VI_SUCCESS) \
{  goto Error; } else

int main (void)
{
    ViRsrc deviceName = "PXI1Slot2";
    int    start1588 = 1;

    ViSession deviceSession = 0;
    ViInt32   status = 0;
    ViChar    errorString[256];

    // Open a session to the timing and synchronization module
    niSyncErrorCheck (niSync_init (deviceName, VI_TRUE, VI_FALSE, &deviceSession));

    // Check input
    if (start1588)
    {
        // Start 1588
        niSyncErrorCheck (niSync_Start1588 (deviceSession));
        printf ("Started\n");
    }
    else 
    {
        // Stop 1588
        niSyncErrorCheck (niSync_Stop1588 (deviceSession));
        printf ("Stopped\n");
    }

Error:

    // Close session
    if (deviceSession)
       niSync_close (deviceSession);

    if (status < VI_SUCCESS)
    {
      niSync_error_message (VI_NULL, status, errorString);

      printf ("Error %d occurred: %s\n",status, errorString);
    }

    return status >= VI_SUCCESS ? EXIT_SUCCESS : EXIT_FAILURE;
}
